pub struct IndexDocumentTask {
pub tn_id: TnId,
pub file_id: Box<str>,
}Expand description
Scheduled per-document index run. See the module docs for the debounce.
Fields
tn_id: TnIdfile_id: Box<str>Trait Implementations
Sourceimpl Debug for IndexDocumentTask
impl Debug for IndexDocumentTask
Sourceimpl<'de> Deserialize<'de> for IndexDocumentTask
impl<'de> Deserialize<'de> for IndexDocumentTask
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for IndexDocumentTask
impl Serialize for IndexDocumentTask
Sourceimpl Task<Arc<AppState>> for IndexDocumentTask
impl Task<Arc<AppState>> for IndexDocumentTask
fn kind() -> &'static str
fn kind_of(&self) -> &'static str
fn build(_id: TaskId, ctx: &str) -> ClResult<Arc<dyn Task<App>>>
fn serialize(&self) -> String
fn run<'life0, 'life1, 'async_trait>(
&'life0 self,
app: &'life1 App,
) -> Pin<Box<dyn Future<Output = ClResult<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sourcefn on_failed<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_state: &'life1 S,
_attempts: u16,
_last_error: &'life2 str,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn on_failed<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_state: &'life1 S,
_attempts: u16,
_last_error: &'life2 str,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Called when the task transitions to
Failed after exhausting retries
(or on the very first failure when no retry policy is set). Lets the
task perform irreversible cleanup — e.g. mark a related domain row as
permanently failed — that should not happen on retryable failures.
Default: no-op.Sourcefn on_attempt_failed<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_state: &'life1 S,
_attempt: u16,
_last_error: &'life2 str,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn on_attempt_failed<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_state: &'life1 S,
_attempt: u16,
_last_error: &'life2 str,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Called after a failure that will be retried, with the zero-based index
of the attempt that just failed. Lets a task tell the user once, on the
first failure, instead of once per retry. Default: no-op. Read more